==> jc-1.4.0.tar.gz: java/util/WeakHashMap__24WeakBucket__24WeakEntry.h <==
// class java.util.WeakHashMap$WeakBucket$WeakEntry

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ae69b99a2ef952f3 java_util_WeakHashMap__24WeakBucket__24WeakEntry

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_WeakHashMap__24WeakBucket__24WeakEntry_H_
#define _JC_java_util_WeakHashMap__24WeakBucket__24WeakEntry_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_WeakHashMap__24WeakBucket$object;

// Typedefs
typedef struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$sub_refs	_jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$sub_refs;
typedef struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$sub_nonrefs	_jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$sub_nonrefs;
typedef struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$refs	_jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$refs;
typedef struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$nonrefs	_jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$nonrefs;
typedef struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object	_jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object;

typedef const struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$vmethods	_jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$vmethods;
typedef const struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$vtable	_jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$vtable;
typedef const struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$vtype	_jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$vtype;

// Constructors
extern void _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$method$_init$0fe78f733caf99c9(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object *, struct _jc_java_util_WeakHashMap__24WeakBucket$object *, struct _jc_java_lang_Object$object *);

// Virtual methods
extern jboolean _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_util_WeakHashMap__24WeakBucket$object *_jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$method$getBucket$b246f0d5f9d0c985(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object *);
extern struct _jc_java_lang_Object$object *_jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$method$getKey$36389701bfdf0ba9(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object *);
extern struct _jc_java_lang_Object$object *_jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$method$getValue$6f8b281a5ffcc94f(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object *);
extern jint _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object *);
extern struct _jc_java_lang_Object$object *_jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$method$setValue$ebae6c539663892b(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_String$object *_jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$method_info$getBucket$b246f0d5f9d0c985;
extern _jc_method _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$method_info$getKey$36389701bfdf0ba9;
extern _jc_method _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$method_info$getValue$6f8b281a5ffcc94f;
extern _jc_method _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$method_info$setValue$ebae6c539663892b;
extern _jc_method _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_util_WeakHashMap__24WeakBucket$object	*(*getBucket$b246f0d5f9d0c985)(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object *);
	struct _jc_java_lang_Object$object	*(*getKey$36389701bfdf0ba9)(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object *);
	struct _jc_java_lang_Object$object	*(*getValue$6f8b281a5ffcc94f)(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object *);
	struct _jc_java_lang_Object$object	*(*setValue$ebae6c539663892b)(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object *);
};

// Vtable
struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$vmethods	java_util_WeakHashMap__24WeakBucket__24WeakEntry;
};

// Vtype
struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$vtype {
	_jc_type			type;
	_jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$sub_refs {
	struct _jc_java_lang_Object$object	*key;
	struct _jc_java_util_WeakHashMap__24WeakBucket$object	*this;
};

// Reference instance fields (object)
struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$refs {
    _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$sub_refs	java_util_WeakHashMap__24WeakBucket__24WeakEntry;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$sub_nonrefs	java_util_WeakHashMap__24WeakBucket__24WeakEntry;
};

// Object instance structure
struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object {
	_jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$vtype	*vtype;
	_jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$vtype _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_WeakHashMap__24WeakBucket__24WeakEntry, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$class_object;

#endif	/* _JC_java_util_WeakHashMap__24WeakBucket__24WeakEntry_H_ */

==> jc-1.4.6.tar.gz: java/util/WeakHashMap__24WeakBucket__24WeakEntry.h <==
// class java.util.WeakHashMap$WeakBucket$WeakEntry

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ae69b99a2ef952f3 java_util_WeakHashMap__24WeakBucket__24WeakEntry

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_WeakHashMap__24WeakBucket__24WeakEntry_H_
#define _JC_java_util_WeakHashMap__24WeakBucket__24WeakEntry_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_WeakHashMap__24WeakBucket$object;

// Typedefs
typedef struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$sub_refs	_jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$sub_refs;
typedef struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$sub_nonrefs	_jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$sub_nonrefs;
typedef struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$refs	_jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$refs;
typedef struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$nonrefs	_jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$nonrefs;
typedef struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object	_jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object;

typedef const struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$vmethods	_jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$vmethods;
typedef const struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$vtable	_jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$vtable;
typedef const struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$vtype	_jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$vtype;

// Constructors
extern void _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$method$_init$0fe78f733caf99c9(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object *, struct _jc_java_util_WeakHashMap__24WeakBucket$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_util_WeakHashMap__24WeakBucket$object *_jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$method$getBucket$b246f0d5f9d0c985(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$method$getKey$36389701bfdf0ba9(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$method$getValue$6f8b281a5ffcc94f(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object *) _JC_JCNI_ATTR;
extern jint _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$method$setValue$ebae6c539663892b(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$method_info$getBucket$b246f0d5f9d0c985;
extern _jc_method _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$method_info$getKey$36389701bfdf0ba9;
extern _jc_method _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$method_info$getValue$6f8b281a5ffcc94f;
extern _jc_method _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$method_info$setValue$ebae6c539663892b;
extern _jc_method _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_util_WeakHashMap__24WeakBucket$object	*(*getBucket$b246f0d5f9d0c985)(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*getKey$36389701bfdf0ba9)(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*getValue$6f8b281a5ffcc94f)(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*setValue$ebae6c539663892b)(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$vmethods	java_util_WeakHashMap__24WeakBucket__24WeakEntry;
};

// Vtype
struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$vtype {
	_jc_type			type;
	_jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$sub_refs {
	struct _jc_java_lang_Object$object	*key;
	struct _jc_java_util_WeakHashMap__24WeakBucket$object	*this;
};

// Reference instance fields (object)
struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$refs {
    _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$sub_refs	java_util_WeakHashMap__24WeakBucket__24WeakEntry;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$sub_nonrefs	java_util_WeakHashMap__24WeakBucket__24WeakEntry;
};

// Object instance structure
struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object {
	_jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$vtype	*vtype;
	_jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$vtype _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_WeakHashMap__24WeakBucket__24WeakEntry, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$class_object;

#endif	/* _JC_java_util_WeakHashMap__24WeakBucket__24WeakEntry_H_ */
